import { formatNumber } from "@/common/number-utils";
import { CachedBedrockMinecraftServer, CachedJavaMinecraftServer } from "mcutils-library";
import Image from "next/image";
import { ReactElement } from "react";
import { Card } from "../card";
import { CodeDialog } from "../code-dialog";
import { Button } from "../ui/button";

type ServerViewProps = {
  /**
   * The server to display.
   */
  server: CachedJavaMinecraftServer | CachedBedrockMinecraftServer;

  /**
   * The favicon for the server.
   */
  favicon: string | undefined;
};

export function ServerView({ server, favicon }: ServerViewProps): ReactElement {
  return (
    <div className="flex flex-col gap-2">
      <Card className="w-max xs:w-fit relative">
        <div className="flex gap-2 flex-col">
          <div className="flex gap-4 flex-col xs:flex-row">
            {favicon && (
              <div className="flex justify-center xs:justify-start">
                <Image
                  className="w-[64px] h-[64px]"
                  src={favicon}
                  width={64}
                  height={64}
                  quality={100}
                  alt="The server's favicon"
                />
              </div>
            )}

            <div className="flex flex-col">
              <h2 className="text-xl text-primary font-semibold">{server.hostname}</h2>
              <div>
                <p>
                  Players online: {formatNumber(server.players.online)}/{formatNumber(server.players.max)}
                </p>
              </div>
            </div>
          </div>

          <div className="bg-background rounded-lg p-2 text-sm xs:text-lg">
            {server.motd.html.map((line, index) => {
              return <p key={index} dangerouslySetInnerHTML={{ __html: line }}></p>;
            })}
          </div>
        </div>
      </Card>
      <div className="8xl:top-0 xs:bottom-0">
        <CodeDialog
          title="Server Data"
          description="The server's data from the API"
          code={JSON.stringify(server, undefined, 2)}
        >
          <Button>View as JSON</Button>
        </CodeDialog>
      </div>
    </div>
  );
}
