import { Metadata } from "next";

type Embed = {
  /**
   * The title of the embed.
   */
  title: string;

  /**
   * The description of the embed.
   */
  description: string;

  /**
   * The image to show as the thumbmail.
   */
  image?: string;
};

/**
 * Generates metadata for a embed.
 *
 * @param title the title of the embed
 * @param description the description of the embed
 * @returns the metadata for the embed
 */
export function generateEmbed({ title, description, image }: Embed): Metadata {
  const metadata: Metadata = {
    title: `${title}`,
    openGraph: {
      title: `${title}`,
      description: description,
    },
    twitter: {
      card: "summary",
    },
  };

  if (image) {
    metadata.openGraph!.images = [
      {
        url: image || "",
      },
    ];
  }

  return metadata;
}
